<?php
/**
 * Widget : Banner Ads
 *
 * @package    Humble
 * @version    1.5
 * @author     Elite Layers <admin@elitelayers.com>
 * @copyright  Copyright (c) 2017, Elite Layers
 * @link       http://demo.elitelayers.com/humble/
 * @license    http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2 or later
 */

/**
 * Core class used to implement a About Author widget.
 *
 * @see WP_Widget
 */
class Humble_Widget_Banner_Ads extends WP_Widget {

	public function __construct() {
		parent::__construct(
			'banner-ads-widget', // Widget ID
			esc_html__( 'Humble: Banner Ads', 'humble' ), // Widget Name.
			array(
				'classname'   => 'banner-ads-widget', // Widget Class.
				'description' => esc_html__( 'A widget that displays banner ads.', 'humble' ), // Widget Description.
			)
		);
	}

	/**
	 * Outputs the content for the current About me widget instance.
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Archives widget instance.
	 */
 	function widget( $args, $instance ) {
 		extract( $args );

 		/* Our variables from the widget settings. */
 		$title = apply_filters('widget_title', $instance['title'] );
 		$ad_image = $instance['ad_image'];
 		$ad_link = $instance['ad_link'];

 		/* Before widget */
 		echo $before_widget;

 		/* Display the widget title if one was input. */
 		if ( $title )
 			echo $before_title . $title . $after_title;

 		?>

 			<div class="banner-ads">

                <?php if($ad_link) : ?>
				<a href="<?php echo esc_url($ad_link); ?>" title="">
				<?php endif; ?>

					<?php if($ad_image) : ?>
						<img src="<?php echo esc_url($ad_image); ?>" alt="" />
					<?php endif; ?>

                <?php if($ad_link) : ?>
				</a>
				<?php endif; ?>

 			</div>

 		<?php

 		/* After widget (defined by themes). */
 		echo $after_widget;
 	}


	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options.
	 *
	 * @param array $old_instance The previous options.
	 *
	 * @return array
	 */

	 function update( $new_instance, $old_instance ) {
	    $instance = $old_instance;

	    /* Strip tags for title and name to remove HTML (important for text inputs). */
	    $instance['title'] = strip_tags( $new_instance['title'] );
	    $instance['ad_image'] = strip_tags( $new_instance['ad_image'] );
	    $instance['ad_link'] = strip_tags( $new_instance['ad_link'] );

	    return $instance;
	 }

	/**
	 * Outputs the settings form for the About me widget.
	 *
	 * @param array $instance Current settings.
	 */
	 function form( $instance ) {

 		/* Set up some default widget settings. */
 		$defaults = array( 'title' => 'About Me', 'ad_image' => '', 'ad_link' => '');
 		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

 		<p>
 			<label for="<?php echo $this->get_field_id( 'ad_image' ); ?>"><?php esc_html_e('Banner Image URL:','humble');?></label>
 			<input id="<?php echo $this->get_field_id( 'ad_image' ); ?>" name="<?php echo $this->get_field_name( 'ad_image' ); ?>" value="<?php echo $instance['ad_image']; ?>" style="width:100%;" /><br />
 		</p>

 		<p>
 			<label for="<?php echo $this->get_field_id( 'ad_link' ); ?>"><?php esc_html_e('Ad URL:','humble');?></label>
 			<input id="<?php echo $this->get_field_id( 'ad_link' ); ?>" name="<?php echo $this->get_field_name( 'ad_link' ); ?>" value="<?php echo $instance['ad_link']; ?>" style="width:100%;" /><br />
 		</p>
	<?php
	}
}

add_action( 'widgets_init',
	create_function( '', 'return register_widget( "Humble_Widget_Banner_Ads" );' )
);

?>
